==> ejc-zhengyuan-impl-3.0.0-20250821.081133-43-sources.jar: com/ejianc/business/prjdocs/bean/PrjperfHandoverEntity.java <==
package com.ejianc.business.prjdocs.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 项目履约交底
 * 
 * @author generator
 * 
 */
@TableName("ejc_prjdocs_prjperf_handover")
public class PrjperfHandoverEntity extends BaseEntity {
	private static final long serialVersionUID = 1L;

	@TableField(value = "bill_state")
	private Integer billState; // 单据审批状态
	@TableField(value = "bill_code")
	private String billCode; // 单据编码
	@TableField(value = "project_id")
	private Long projectId; // 项目id
	@TableField(value = "project_name")
	private String projectName; // 项目名称
	@TableField(value="project_department_id")
	private Long projectDepartmentId; // 项目部id
	@TableField(value="org_id")
	private Long orgId; // 所属单位id
	@TableField(value = "org_name")
	private String orgName; // 所属单位名称
	@TableField(value = "project_leader")
	private String projectLeader; // 项目负责人
	@TableField(value = "project_type")
	private String projectType; // 项目类型
	@TableField(value = "project_scale")
	private String projectScale; // 项目规模
	@TableField(value = "project_start_date")
	private Date projectStartDate; // 项目开工日期
	@TableField(value = "project_end_date")
	private Date projectEndDate; // 项目结束日期
	@TableField(value = "project_address")
	private String projectAddress; // 项目地址
	@TableField(value = "employee_id")
	private Long employeeId; // 交底人ID
	@TableField(value = "employee_name")
	private String employeeName; // 交底人姓名
	@TableField(value = "handover_date")
	private Date handoverDate; // 交底时间
	@TableField(value = "handover_content")
	private String handoverContent; // 交底内容
	@TableField(value = "remark")
	private String remark; // 备注信息

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public Long getProjectDepartmentId() {
		return projectDepartmentId;
	}

	public void setProjectDepartmentId(Long projectDepartmentId) {
		this.projectDepartmentId = projectDepartmentId;
	}

	public Long getOrgId() {
		return orgId;
	}

	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public String getOrgName() {
		return orgName;
	}

	public void setOrgName(String orgName) {
		this.orgName = orgName;
	}

	public String getProjectLeader() {
		return projectLeader;
	}

	public void setProjectLeader(String projectLeader) {
		this.projectLeader = projectLeader;
	}

	public String getProjectType() {
		return projectType;
	}

	public void setProjectType(String projectType) {
		this.projectType = projectType;
	}

	public String getProjectScale() {
		return projectScale;
	}

	public void setProjectScale(String projectScale) {
		this.projectScale = projectScale;
	}

	public Date getProjectStartDate() {
		return projectStartDate;
	}

	public void setProjectStartDate(Date projectStartDate) {
		this.projectStartDate = projectStartDate;
	}

	public Date getProjectEndDate() {
		return projectEndDate;
	}

	public void setProjectEndDate(Date projectEndDate) {
		this.projectEndDate = projectEndDate;
	}

	public String getProjectAddress() {
		return projectAddress;
	}

	public void setProjectAddress(String projectAddress) {
		this.projectAddress = projectAddress;
	}

	public Long getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getHandoverDate() {
		return handoverDate;
	}

	public void setHandoverDate(Date handoverDate) {
		this.handoverDate = handoverDate;
	}

	public String getHandoverContent() {
		return handoverContent;
	}

	public void setHandoverContent(String handoverContent) {
		this.handoverContent = handoverContent;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

}

==> ejc-zhengyuan-impl-3.0.0-20251202.033713-51-sources.jar: com/ejianc/business/prjdocs/bean/PrjperfHandoverEntity.java <==
package com.ejianc.business.prjdocs.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 项目履约交底
 * 
 * @author generator
 * 
 */
@TableName("ejc_prjdocs_prjperf_handover")
public class PrjperfHandoverEntity extends BaseEntity {
	private static final long serialVersionUID = 1L;

	@TableField(value = "bill_state")
	private Integer billState; // 单据审批状态
	@TableField(value = "bill_code")
	private String billCode; // 单据编码
	@TableField(value = "project_id")
	private Long projectId; // 项目id
	@TableField(value = "project_name")
	private String projectName; // 项目名称
	@TableField(value="project_department_id")
	private Long projectDepartmentId; // 项目部id
	@TableField(value="org_id")
	private Long orgId; // 所属单位id
	@TableField(value = "org_name")
	private String orgName; // 所属单位名称
	@TableField(value = "project_leader")
	private String projectLeader; // 项目负责人
	@TableField(value = "project_type")
	private String projectType; // 项目类型
	@TableField(value = "project_scale")
	private String projectScale; // 项目规模
	@TableField(value = "project_start_date")
	private Date projectStartDate; // 项目开工日期
	@TableField(value = "project_end_date")
	private Date projectEndDate; // 项目结束日期
	@TableField(value = "project_address")
	private String projectAddress; // 项目地址
	@TableField(value = "employee_id")
	private String employeeId; // 交底人ID
	@TableField(value = "employee_name")
	private String employeeName; // 交底人姓名
	@TableField(value = "handover_date")
	private Date handoverDate; // 交底时间
	@TableField(value = "handover_content")
	private String handoverContent; // 交底内容
	@TableField(value = "remark")
	private String remark; // 备注信息

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public Long getProjectDepartmentId() {
		return projectDepartmentId;
	}

	public void setProjectDepartmentId(Long projectDepartmentId) {
		this.projectDepartmentId = projectDepartmentId;
	}

	public Long getOrgId() {
		return orgId;
	}

	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public String getOrgName() {
		return orgName;
	}

	public void setOrgName(String orgName) {
		this.orgName = orgName;
	}

	public String getProjectLeader() {
		return projectLeader;
	}

	public void setProjectLeader(String projectLeader) {
		this.projectLeader = projectLeader;
	}

	public String getProjectType() {
		return projectType;
	}

	public void setProjectType(String projectType) {
		this.projectType = projectType;
	}

	public String getProjectScale() {
		return projectScale;
	}

	public void setProjectScale(String projectScale) {
		this.projectScale = projectScale;
	}

	public Date getProjectStartDate() {
		return projectStartDate;
	}

	public void setProjectStartDate(Date projectStartDate) {
		this.projectStartDate = projectStartDate;
	}

	public Date getProjectEndDate() {
		return projectEndDate;
	}

	public void setProjectEndDate(Date projectEndDate) {
		this.projectEndDate = projectEndDate;
	}

	public String getProjectAddress() {
		return projectAddress;
	}

	public void setProjectAddress(String projectAddress) {
		this.projectAddress = projectAddress;
	}

	public String getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(String employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getHandoverDate() {
		return handoverDate;
	}

	public void setHandoverDate(Date handoverDate) {
		this.handoverDate = handoverDate;
	}

	public String getHandoverContent() {
		return handoverContent;
	}

	public void setHandoverContent(String handoverContent) {
		this.handoverContent = handoverContent;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

}
